==> hybrid-0.0.3.tar.gz: example/android/app/src/main/kotlin/com/deplay/one/hybrid_example/PageRouter.java <==
package com.deplay.one.hybrid_example;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.util.Log;

import java.util.HashMap;
import java.util.Map;

import com.deplay.one.hybrid_example.HybridActivity;
import com.deplay.one.hybrid_example.activity.CanvasActivity;

public class PageRouter {

    public final static Map<String, String> pageName = new HashMap<String, String>() {{

        put("first", "first");
        put("second", "second");
        put("tab", "tab");
        put("sample://flutterPage", "flutterPage");
    }};

    public static final String CANVAS_PAGE_URL = "sample://canvasPage";
    public static final String HYBRID_PAGE_URL = "sample://hybridPage";


    public static boolean openPageByUrl(Context context, String url, Map params) {
        return openPageByUrl(context, url, params, 0);
    }

    public static boolean openPageByUrl(Context context, String url, Map params, int requestCode) {

        String path = url.split("\\?")[0];

        Log.i("openPageByUrl",path);
        try {
           if (url.startsWith(HYBRID_PAGE_URL)) {
                Intent hybridIntent=new Intent(context, HybridActivity.class);
                // hybridIntent.putExtra("enable-software-rendering", true);
                context.startActivity(hybridIntent);
                return true;
            } else if (url.startsWith(CANVAS_PAGE_URL)) {
                context.startActivity(new Intent(context, CanvasActivity.class));
                return true;
            }

            return false;

        } catch (Throwable t) {
            return false;
        }
    }
}

==> hybrid-0.0.5.tar.gz: example/android/app/src/main/kotlin/com/deplay/one/hybrid_example/PageRouter.java <==
package com.deplay.one.hybrid_example;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.util.Log;

import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

import com.deplay.one.hybrid_example.HybridActivity;
import com.deplay.one.hybrid_example.activity.CanvasActivity;

import io.flutter.embedding.android.FlutterActivity;

public class PageRouter {

    public final static Map<String, String> pageName = new HashMap<String, String>() {{

        put("first", "first");
        put("second", "second");
        put("tab", "tab");
        put("sample://flutterPage", "flutterPage");
    }};

    public static final String CANVAS_PAGE_URL = "sample://canvasPage";
    public static final String HYBRID_PAGE_URL = "sample://hybridPage";


    public static boolean openPageByUrl(Context context, String url, Map params) {
        return openPageByUrl(context, url, params, 0);
    }

    public static boolean openPageByUrl(Context context, String url, Map params, int requestCode) {

        String path = url.split("\\?")[0];

        Log.i("openPageByUrl",path);
        try {
           if (url.startsWith(HYBRID_PAGE_URL)) {
//                 Intent hybridIntent=new Intent(context, HybridActivity.class);
//                 hybridIntent.putExtra("route","http://192.168.2.216:3000/api/bundleJson");
//                 // hybridIntent.putExtra("enable-software-rendering", true);
//                 context.startActivity(hybridIntent);

               context.startActivity(
                       FlutterActivity
                               .withCachedEngine("my_engine_id")
                               .build(Objects.requireNonNull(context))
                               .setClass(context,HybridActivity.class)
                               .putExtra("route","http://192.168.2.216:3000/api/bundleJson")
               );


                return true;
            } else if (url.startsWith(CANVAS_PAGE_URL)) {
                context.startActivity(new Intent(context, CanvasActivity.class));
                return true;
            }

            return false;

        } catch (Throwable t) {
            return false;
        }
    }
}
